@@ -44,7 +44,7 @@ $EXPORT_TAGS{ all } = [@EXPORT_OK];
 our $DIE_ON_ERROR = 0;
 our $PROMOTE_N32 = 1;
 
-our $VERSION = '3.021';
+our $VERSION = '3.022';
 
 sub IP {
     return Net::IPAddress::Util->new($_[0]);
@@ -59,7 +59,7 @@ sub new {
         $normal = $address;
     }
     elsif (ref($address) eq 'ARRAY' && @$address == 4) {
-        $normal = [ unpack 'U16', pack 'N4', @$address ];
+        $normal = [ unpack 'C16', pack 'N4', @$address ];
     }
     elsif (ref $address and eval { $address->isa(__PACKAGE__) }) {
         return bless { address => $address->{ address } } => $class;
@@ -77,7 +77,7 @@ sub new {
             0, 0, 0, 0,
             0, 0, 0, 0,
             0, 0, 0xff, 0xff,
-            unpack('U4', pack('N', $address))
+            unpack('C4', pack('N', $address))
         ];
     }
     elsif ("$address" =~ /^([0-9a-f]{32})$/smio) {
@@ -86,7 +86,7 @@ sub new {
         my $raw = Math::BigInt->from_hex("$fresh");
         while ($raw > 0) {
             my $word = $raw->copy->band(0xffffffff);
-            unshift @$normal, unpack('U4', pack('N', $word));
+            unshift @$normal, unpack('C4', pack('N', $word));
             $raw = $raw->copy->brsft(32);
         }
         while (@$normal < 16) {
@@ -99,7 +99,7 @@ sub new {
         my $raw = Math::BigInt->new("$address");
         while ($raw > 0) {
             my $word = $raw->copy->band(0xffffffff);
-            unshift @$normal, unpack('U4', pack('N', $word));
+            unshift @$normal, unpack('C4', pack('N', $word));
             $raw = $raw->copy->brsft(32);
         }
         while (@$normal < 16) {
@@ -139,13 +139,13 @@ sub new {
 
 sub is_ipv4 {
     my $self = shift;
-    my @octets = unpack 'U16', $self->{ address };
+    my @octets = unpack 'C16', $self->{ address };
     return $octets[ 10 ] == 0xff && $octets[ 11 ] == 0xff && (!grep { $_ } @octets[ 0 .. 9 ]);
 }
 
 sub ipv4 {
     my $self = shift;
-    return join '.', unpack 'U4', substr($self->{ address }, -4);
+    return join '.', unpack 'C4', substr($self->{ address }, -4);
 }
 
 sub as_n32 {
@@ -173,7 +173,7 @@ sub as_n128 {
 
 sub normal_form {
     my $self = shift;
-    my $hex = join('', map { sprintf('%02x', $_) } unpack('U16', $self->{ address }));
+    my $hex = join('', map { sprintf('%02x', $_) } unpack('C16', $self->{ address }));
     $hex = substr(('0' x 32) . $hex, -32);
     return lc $hex;
 }
@@ -284,7 +284,7 @@ sub _shift_left {
     my $self = shift;
     my ($rhs, $swapped) = @_;
     my ($pow, $mask) = $self->_pow_mask;
-    my @l = reverse unpack('U16', $self->{ address });
+    my @l = reverse unpack('C16', $self->{ address });
     my @rv;
     for my $octet (0 .. 15) {
         $rv[$octet] += $l[$octet] << $rhs;
@@ -302,7 +302,7 @@ sub _shift_right {
     my $self = shift;
     my ($rhs, $swapped) = @_;
     my ($pow, $mask) = $self->_pow_mask;
-    my @l = unpack('U16', $self->{ address });
+    my @l = unpack('C16', $self->{ address });
     my @rv;
     for my $octet (0 .. 15) {
         $rv[$octet] += $l[$octet] >> $rhs;
@@ -355,7 +355,7 @@ sub _bor {
 
 sub _neg {
     my $self = shift;
-    my @n = unpack('U16', $self->{ address });
+    my @n = unpack('C16', $self->{ address });
     my ($pow, $mask) = $self->_pow_mask;
     my @rv = map { 255 - $_ } @n;
     return Net::IPAddress::Util->new(\@rv);
@@ -435,7 +435,7 @@ sub explode_ip {
 }
 
 sub implode_ip {
-    return Net::IPAddress::Util->new([ unpack 'U16', pack 'B128', join '', map { split // } @_ ]);
+    return Net::IPAddress::Util->new([ unpack 'C16', pack 'B128', join '', map { split // } @_ ]);
 }
 
 sub n32_to_ipv4 { local $PROMOTE_N32 = 1; return IP(@_) }
@@ -456,7 +456,7 @@ sub radix_sort (\@) {
     # a fair margin. However, it _does_ discard duplicates, so ymmv.
     shift if $_[0] eq __PACKAGE__;
     my $array = shift;
-    my $from = [ map { [ unpack 'U16', $_->{ address } ] } @$array ];
+    my $from = [ map { [ unpack 'C16', $_->{ address } ] } @$array ];
     my $to;
     for (my $i = 15; $i >= 0; $i--) {
         $to = [];
@@ -465,7 +465,7 @@ sub radix_sort (\@) {
         }
         $from = [ map { @{$_ // []} } @$to ];
     }
-    my @rv = map { IP(pack 'U16', @$_) } @$from;
+    my @rv = map { IP(pack 'C16', @$_) } @$from;
     return @rv;
 }
 
