@@ -1,8 +1,9 @@
 package Net::IPAddress::Util::Collection::Tie;
 
+use strict;
+use warnings;
 use 5.012;
 use utf8;
-no diagnostics;
 
 use Carp qw( confess );
 
